# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six
from tb_rest_client.models.models_pe.tenant_profile_configuration import TenantProfileConfiguration  # noqa: F401,E501

class DefaultTenantProfileConfiguration(TenantProfileConfiguration):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_devices': 'int',
        'max_assets': 'int',
        'max_customers': 'int',
        'max_users': 'int',
        'max_dashboards': 'int',
        'max_rule_chains': 'int',
        'max_resources_in_bytes': 'int',
        'max_ota_packages_in_bytes': 'int',
        'max_resource_size': 'int',
        'max_integrations': 'int',
        'max_converters': 'int',
        'max_scheduler_events': 'int',
        'transport_tenant_msg_rate_limit': 'str',
        'transport_tenant_telemetry_msg_rate_limit': 'str',
        'transport_tenant_telemetry_data_points_rate_limit': 'str',
        'transport_device_msg_rate_limit': 'str',
        'transport_device_telemetry_msg_rate_limit': 'str',
        'transport_device_telemetry_data_points_rate_limit': 'str',
        'transport_gateway_msg_rate_limit': 'str',
        'transport_gateway_telemetry_msg_rate_limit': 'str',
        'transport_gateway_telemetry_data_points_rate_limit': 'str',
        'transport_gateway_device_msg_rate_limit': 'str',
        'transport_gateway_device_telemetry_msg_rate_limit': 'str',
        'transport_gateway_device_telemetry_data_points_rate_limit': 'str',
        'integration_msgs_per_tenant_rate_limit': 'str',
        'integration_msgs_per_device_rate_limit': 'str',
        'tenant_entity_export_rate_limit': 'str',
        'tenant_entity_import_rate_limit': 'str',
        'tenant_notification_requests_rate_limit': 'str',
        'tenant_notification_requests_per_rule_rate_limit': 'str',
        'max_transport_messages': 'int',
        'max_transport_data_points': 'int',
        'max_re_executions': 'int',
        'max_js_executions': 'int',
        'max_tbel_executions': 'int',
        'max_dp_storage_days': 'int',
        'max_rule_node_executions_per_message': 'int',
        'max_emails': 'int',
        'sms_enabled': 'bool',
        'max_sms': 'int',
        'max_created_alarms': 'int',
        'tenant_server_rest_limits_configuration': 'str',
        'customer_server_rest_limits_configuration': 'str',
        'max_ws_sessions_per_tenant': 'int',
        'max_ws_sessions_per_customer': 'int',
        'max_ws_sessions_per_regular_user': 'int',
        'max_ws_sessions_per_public_user': 'int',
        'ws_msg_queue_limit_per_session': 'int',
        'max_ws_subscriptions_per_tenant': 'int',
        'max_ws_subscriptions_per_customer': 'int',
        'max_ws_subscriptions_per_regular_user': 'int',
        'max_ws_subscriptions_per_public_user': 'int',
        'ws_updates_per_session_rate_limit': 'str',
        'cassandra_query_tenant_rate_limits_configuration': 'str',
        'edge_event_rate_limits': 'str',
        'edge_event_rate_limits_per_edge': 'str',
        'edge_uplink_messages_rate_limits': 'str',
        'edge_uplink_messages_rate_limits_per_edge': 'str',
        'default_storage_ttl_days': 'int',
        'alarms_ttl_days': 'int',
        'rpc_ttl_days': 'int',
        'queue_stats_ttl_days': 'int',
        'rule_engine_exceptions_ttl_days': 'int',
        'warn_threshold': 'float'
    }
    if hasattr(TenantProfileConfiguration, "swagger_types"):
        swagger_types.update(TenantProfileConfiguration.swagger_types)

    attribute_map = {
        'max_devices': 'maxDevices',
        'max_assets': 'maxAssets',
        'max_customers': 'maxCustomers',
        'max_users': 'maxUsers',
        'max_dashboards': 'maxDashboards',
        'max_rule_chains': 'maxRuleChains',
        'max_resources_in_bytes': 'maxResourcesInBytes',
        'max_ota_packages_in_bytes': 'maxOtaPackagesInBytes',
        'max_resource_size': 'maxResourceSize',
        'max_integrations': 'maxIntegrations',
        'max_converters': 'maxConverters',
        'max_scheduler_events': 'maxSchedulerEvents',
        'transport_tenant_msg_rate_limit': 'transportTenantMsgRateLimit',
        'transport_tenant_telemetry_msg_rate_limit': 'transportTenantTelemetryMsgRateLimit',
        'transport_tenant_telemetry_data_points_rate_limit': 'transportTenantTelemetryDataPointsRateLimit',
        'transport_device_msg_rate_limit': 'transportDeviceMsgRateLimit',
        'transport_device_telemetry_msg_rate_limit': 'transportDeviceTelemetryMsgRateLimit',
        'transport_device_telemetry_data_points_rate_limit': 'transportDeviceTelemetryDataPointsRateLimit',
        'transport_gateway_msg_rate_limit': 'transportGatewayMsgRateLimit',
        'transport_gateway_telemetry_msg_rate_limit': 'transportGatewayTelemetryMsgRateLimit',
        'transport_gateway_telemetry_data_points_rate_limit': 'transportGatewayTelemetryDataPointsRateLimit',
        'transport_gateway_device_msg_rate_limit': 'transportGatewayDeviceMsgRateLimit',
        'transport_gateway_device_telemetry_msg_rate_limit': 'transportGatewayDeviceTelemetryMsgRateLimit',
        'transport_gateway_device_telemetry_data_points_rate_limit': 'transportGatewayDeviceTelemetryDataPointsRateLimit',
        'integration_msgs_per_tenant_rate_limit': 'integrationMsgsPerTenantRateLimit',
        'integration_msgs_per_device_rate_limit': 'integrationMsgsPerDeviceRateLimit',
        'tenant_entity_export_rate_limit': 'tenantEntityExportRateLimit',
        'tenant_entity_import_rate_limit': 'tenantEntityImportRateLimit',
        'tenant_notification_requests_rate_limit': 'tenantNotificationRequestsRateLimit',
        'tenant_notification_requests_per_rule_rate_limit': 'tenantNotificationRequestsPerRuleRateLimit',
        'max_transport_messages': 'maxTransportMessages',
        'max_transport_data_points': 'maxTransportDataPoints',
        'max_re_executions': 'maxREExecutions',
        'max_js_executions': 'maxJSExecutions',
        'max_tbel_executions': 'maxTbelExecutions',
        'max_dp_storage_days': 'maxDPStorageDays',
        'max_rule_node_executions_per_message': 'maxRuleNodeExecutionsPerMessage',
        'max_emails': 'maxEmails',
        'sms_enabled': 'smsEnabled',
        'max_sms': 'maxSms',
        'max_created_alarms': 'maxCreatedAlarms',
        'tenant_server_rest_limits_configuration': 'tenantServerRestLimitsConfiguration',
        'customer_server_rest_limits_configuration': 'customerServerRestLimitsConfiguration',
        'max_ws_sessions_per_tenant': 'maxWsSessionsPerTenant',
        'max_ws_sessions_per_customer': 'maxWsSessionsPerCustomer',
        'max_ws_sessions_per_regular_user': 'maxWsSessionsPerRegularUser',
        'max_ws_sessions_per_public_user': 'maxWsSessionsPerPublicUser',
        'ws_msg_queue_limit_per_session': 'wsMsgQueueLimitPerSession',
        'max_ws_subscriptions_per_tenant': 'maxWsSubscriptionsPerTenant',
        'max_ws_subscriptions_per_customer': 'maxWsSubscriptionsPerCustomer',
        'max_ws_subscriptions_per_regular_user': 'maxWsSubscriptionsPerRegularUser',
        'max_ws_subscriptions_per_public_user': 'maxWsSubscriptionsPerPublicUser',
        'ws_updates_per_session_rate_limit': 'wsUpdatesPerSessionRateLimit',
        'cassandra_query_tenant_rate_limits_configuration': 'cassandraQueryTenantRateLimitsConfiguration',
        'edge_event_rate_limits': 'edgeEventRateLimits',
        'edge_event_rate_limits_per_edge': 'edgeEventRateLimitsPerEdge',
        'edge_uplink_messages_rate_limits': 'edgeUplinkMessagesRateLimits',
        'edge_uplink_messages_rate_limits_per_edge': 'edgeUplinkMessagesRateLimitsPerEdge',
        'default_storage_ttl_days': 'defaultStorageTtlDays',
        'alarms_ttl_days': 'alarmsTtlDays',
        'rpc_ttl_days': 'rpcTtlDays',
        'queue_stats_ttl_days': 'queueStatsTtlDays',
        'rule_engine_exceptions_ttl_days': 'ruleEngineExceptionsTtlDays',
        'warn_threshold': 'warnThreshold'
    }
    if hasattr(TenantProfileConfiguration, "attribute_map"):
        attribute_map.update(TenantProfileConfiguration.attribute_map)

    def __init__(self, max_devices=None, max_assets=None, max_customers=None, max_users=None, max_dashboards=None, max_rule_chains=None, max_resources_in_bytes=None, max_ota_packages_in_bytes=None, max_resource_size=None, max_integrations=None, max_converters=None, max_scheduler_events=None, transport_tenant_msg_rate_limit=None, transport_tenant_telemetry_msg_rate_limit=None, transport_tenant_telemetry_data_points_rate_limit=None, transport_device_msg_rate_limit=None, transport_device_telemetry_msg_rate_limit=None, transport_device_telemetry_data_points_rate_limit=None, transport_gateway_msg_rate_limit=None, transport_gateway_telemetry_msg_rate_limit=None, transport_gateway_telemetry_data_points_rate_limit=None, transport_gateway_device_msg_rate_limit=None, transport_gateway_device_telemetry_msg_rate_limit=None, transport_gateway_device_telemetry_data_points_rate_limit=None, integration_msgs_per_tenant_rate_limit=None, integration_msgs_per_device_rate_limit=None, tenant_entity_export_rate_limit=None, tenant_entity_import_rate_limit=None, tenant_notification_requests_rate_limit=None, tenant_notification_requests_per_rule_rate_limit=None, max_transport_messages=None, max_transport_data_points=None, max_re_executions=None, max_js_executions=None, max_tbel_executions=None, max_dp_storage_days=None, max_rule_node_executions_per_message=None, max_emails=None, sms_enabled=None, max_sms=None, max_created_alarms=None, tenant_server_rest_limits_configuration=None, customer_server_rest_limits_configuration=None, max_ws_sessions_per_tenant=None, max_ws_sessions_per_customer=None, max_ws_sessions_per_regular_user=None, max_ws_sessions_per_public_user=None, ws_msg_queue_limit_per_session=None, max_ws_subscriptions_per_tenant=None, max_ws_subscriptions_per_customer=None, max_ws_subscriptions_per_regular_user=None, max_ws_subscriptions_per_public_user=None, ws_updates_per_session_rate_limit=None, cassandra_query_tenant_rate_limits_configuration=None, edge_event_rate_limits=None, edge_event_rate_limits_per_edge=None, edge_uplink_messages_rate_limits=None, edge_uplink_messages_rate_limits_per_edge=None, default_storage_ttl_days=None, alarms_ttl_days=None, rpc_ttl_days=None, queue_stats_ttl_days=None, rule_engine_exceptions_ttl_days=None, warn_threshold=None, *args, **kwargs):  # noqa: E501
        """DefaultTenantProfileConfiguration - a model defined in Swagger"""  # noqa: E501
        self._max_devices = None
        self._max_assets = None
        self._max_customers = None
        self._max_users = None
        self._max_dashboards = None
        self._max_rule_chains = None
        self._max_resources_in_bytes = None
        self._max_ota_packages_in_bytes = None
        self._max_resource_size = None
        self._max_integrations = None
        self._max_converters = None
        self._max_scheduler_events = None
        self._transport_tenant_msg_rate_limit = None
        self._transport_tenant_telemetry_msg_rate_limit = None
        self._transport_tenant_telemetry_data_points_rate_limit = None
        self._transport_device_msg_rate_limit = None
        self._transport_device_telemetry_msg_rate_limit = None
        self._transport_device_telemetry_data_points_rate_limit = None
        self._transport_gateway_msg_rate_limit = None
        self._transport_gateway_telemetry_msg_rate_limit = None
        self._transport_gateway_telemetry_data_points_rate_limit = None
        self._transport_gateway_device_msg_rate_limit = None
        self._transport_gateway_device_telemetry_msg_rate_limit = None
        self._transport_gateway_device_telemetry_data_points_rate_limit = None
        self._integration_msgs_per_tenant_rate_limit = None
        self._integration_msgs_per_device_rate_limit = None
        self._tenant_entity_export_rate_limit = None
        self._tenant_entity_import_rate_limit = None
        self._tenant_notification_requests_rate_limit = None
        self._tenant_notification_requests_per_rule_rate_limit = None
        self._max_transport_messages = None
        self._max_transport_data_points = None
        self._max_re_executions = None
        self._max_js_executions = None
        self._max_tbel_executions = None
        self._max_dp_storage_days = None
        self._max_rule_node_executions_per_message = None
        self._max_emails = None
        self._sms_enabled = None
        self._max_sms = None
        self._max_created_alarms = None
        self._tenant_server_rest_limits_configuration = None
        self._customer_server_rest_limits_configuration = None
        self._max_ws_sessions_per_tenant = None
        self._max_ws_sessions_per_customer = None
        self._max_ws_sessions_per_regular_user = None
        self._max_ws_sessions_per_public_user = None
        self._ws_msg_queue_limit_per_session = None
        self._max_ws_subscriptions_per_tenant = None
        self._max_ws_subscriptions_per_customer = None
        self._max_ws_subscriptions_per_regular_user = None
        self._max_ws_subscriptions_per_public_user = None
        self._ws_updates_per_session_rate_limit = None
        self._cassandra_query_tenant_rate_limits_configuration = None
        self._edge_event_rate_limits = None
        self._edge_event_rate_limits_per_edge = None
        self._edge_uplink_messages_rate_limits = None
        self._edge_uplink_messages_rate_limits_per_edge = None
        self._default_storage_ttl_days = None
        self._alarms_ttl_days = None
        self._rpc_ttl_days = None
        self._queue_stats_ttl_days = None
        self._rule_engine_exceptions_ttl_days = None
        self._warn_threshold = None
        self.discriminator = None
        if max_devices is not None:
            self.max_devices = max_devices
        if max_assets is not None:
            self.max_assets = max_assets
        if max_customers is not None:
            self.max_customers = max_customers
        if max_users is not None:
            self.max_users = max_users
        if max_dashboards is not None:
            self.max_dashboards = max_dashboards
        if max_rule_chains is not None:
            self.max_rule_chains = max_rule_chains
        if max_resources_in_bytes is not None:
            self.max_resources_in_bytes = max_resources_in_bytes
        if max_ota_packages_in_bytes is not None:
            self.max_ota_packages_in_bytes = max_ota_packages_in_bytes
        if max_resource_size is not None:
            self.max_resource_size = max_resource_size
        if max_integrations is not None:
            self.max_integrations = max_integrations
        if max_converters is not None:
            self.max_converters = max_converters
        if max_scheduler_events is not None:
            self.max_scheduler_events = max_scheduler_events
        if transport_tenant_msg_rate_limit is not None:
            self.transport_tenant_msg_rate_limit = transport_tenant_msg_rate_limit
        if transport_tenant_telemetry_msg_rate_limit is not None:
            self.transport_tenant_telemetry_msg_rate_limit = transport_tenant_telemetry_msg_rate_limit
        if transport_tenant_telemetry_data_points_rate_limit is not None:
            self.transport_tenant_telemetry_data_points_rate_limit = transport_tenant_telemetry_data_points_rate_limit
        if transport_device_msg_rate_limit is not None:
            self.transport_device_msg_rate_limit = transport_device_msg_rate_limit
        if transport_device_telemetry_msg_rate_limit is not None:
            self.transport_device_telemetry_msg_rate_limit = transport_device_telemetry_msg_rate_limit
        if transport_device_telemetry_data_points_rate_limit is not None:
            self.transport_device_telemetry_data_points_rate_limit = transport_device_telemetry_data_points_rate_limit
        if transport_gateway_msg_rate_limit is not None:
            self.transport_gateway_msg_rate_limit = transport_gateway_msg_rate_limit
        if transport_gateway_telemetry_msg_rate_limit is not None:
            self.transport_gateway_telemetry_msg_rate_limit = transport_gateway_telemetry_msg_rate_limit
        if transport_gateway_telemetry_data_points_rate_limit is not None:
            self.transport_gateway_telemetry_data_points_rate_limit = transport_gateway_telemetry_data_points_rate_limit
        if transport_gateway_device_msg_rate_limit is not None:
            self.transport_gateway_device_msg_rate_limit = transport_gateway_device_msg_rate_limit
        if transport_gateway_device_telemetry_msg_rate_limit is not None:
            self.transport_gateway_device_telemetry_msg_rate_limit = transport_gateway_device_telemetry_msg_rate_limit
        if transport_gateway_device_telemetry_data_points_rate_limit is not None:
            self.transport_gateway_device_telemetry_data_points_rate_limit = transport_gateway_device_telemetry_data_points_rate_limit
        if integration_msgs_per_tenant_rate_limit is not None:
            self.integration_msgs_per_tenant_rate_limit = integration_msgs_per_tenant_rate_limit
        if integration_msgs_per_device_rate_limit is not None:
            self.integration_msgs_per_device_rate_limit = integration_msgs_per_device_rate_limit
        if tenant_entity_export_rate_limit is not None:
            self.tenant_entity_export_rate_limit = tenant_entity_export_rate_limit
        if tenant_entity_import_rate_limit is not None:
            self.tenant_entity_import_rate_limit = tenant_entity_import_rate_limit
        if tenant_notification_requests_rate_limit is not None:
            self.tenant_notification_requests_rate_limit = tenant_notification_requests_rate_limit
        if tenant_notification_requests_per_rule_rate_limit is not None:
            self.tenant_notification_requests_per_rule_rate_limit = tenant_notification_requests_per_rule_rate_limit
        if max_transport_messages is not None:
            self.max_transport_messages = max_transport_messages
        if max_transport_data_points is not None:
            self.max_transport_data_points = max_transport_data_points
        if max_re_executions is not None:
            self.max_re_executions = max_re_executions
        if max_js_executions is not None:
            self.max_js_executions = max_js_executions
        if max_tbel_executions is not None:
            self.max_tbel_executions = max_tbel_executions
        if max_dp_storage_days is not None:
            self.max_dp_storage_days = max_dp_storage_days
        if max_rule_node_executions_per_message is not None:
            self.max_rule_node_executions_per_message = max_rule_node_executions_per_message
        if max_emails is not None:
            self.max_emails = max_emails
        if sms_enabled is not None:
            self.sms_enabled = sms_enabled
        if max_sms is not None:
            self.max_sms = max_sms
        if max_created_alarms is not None:
            self.max_created_alarms = max_created_alarms
        if tenant_server_rest_limits_configuration is not None:
            self.tenant_server_rest_limits_configuration = tenant_server_rest_limits_configuration
        if customer_server_rest_limits_configuration is not None:
            self.customer_server_rest_limits_configuration = customer_server_rest_limits_configuration
        if max_ws_sessions_per_tenant is not None:
            self.max_ws_sessions_per_tenant = max_ws_sessions_per_tenant
        if max_ws_sessions_per_customer is not None:
            self.max_ws_sessions_per_customer = max_ws_sessions_per_customer
        if max_ws_sessions_per_regular_user is not None:
            self.max_ws_sessions_per_regular_user = max_ws_sessions_per_regular_user
        if max_ws_sessions_per_public_user is not None:
            self.max_ws_sessions_per_public_user = max_ws_sessions_per_public_user
        if ws_msg_queue_limit_per_session is not None:
            self.ws_msg_queue_limit_per_session = ws_msg_queue_limit_per_session
        if max_ws_subscriptions_per_tenant is not None:
            self.max_ws_subscriptions_per_tenant = max_ws_subscriptions_per_tenant
        if max_ws_subscriptions_per_customer is not None:
            self.max_ws_subscriptions_per_customer = max_ws_subscriptions_per_customer
        if max_ws_subscriptions_per_regular_user is not None:
            self.max_ws_subscriptions_per_regular_user = max_ws_subscriptions_per_regular_user
        if max_ws_subscriptions_per_public_user is not None:
            self.max_ws_subscriptions_per_public_user = max_ws_subscriptions_per_public_user
        if ws_updates_per_session_rate_limit is not None:
            self.ws_updates_per_session_rate_limit = ws_updates_per_session_rate_limit
        if cassandra_query_tenant_rate_limits_configuration is not None:
            self.cassandra_query_tenant_rate_limits_configuration = cassandra_query_tenant_rate_limits_configuration
        if edge_event_rate_limits is not None:
            self.edge_event_rate_limits = edge_event_rate_limits
        if edge_event_rate_limits_per_edge is not None:
            self.edge_event_rate_limits_per_edge = edge_event_rate_limits_per_edge
        if edge_uplink_messages_rate_limits is not None:
            self.edge_uplink_messages_rate_limits = edge_uplink_messages_rate_limits
        if edge_uplink_messages_rate_limits_per_edge is not None:
            self.edge_uplink_messages_rate_limits_per_edge = edge_uplink_messages_rate_limits_per_edge
        if default_storage_ttl_days is not None:
            self.default_storage_ttl_days = default_storage_ttl_days
        if alarms_ttl_days is not None:
            self.alarms_ttl_days = alarms_ttl_days
        if rpc_ttl_days is not None:
            self.rpc_ttl_days = rpc_ttl_days
        if queue_stats_ttl_days is not None:
            self.queue_stats_ttl_days = queue_stats_ttl_days
        if rule_engine_exceptions_ttl_days is not None:
            self.rule_engine_exceptions_ttl_days = rule_engine_exceptions_ttl_days
        if warn_threshold is not None:
            self.warn_threshold = warn_threshold
        TenantProfileConfiguration.__init__(self, *args, **kwargs)

    @property
    def max_devices(self):
        """Gets the max_devices of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_devices of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_devices

    @max_devices.setter
    def max_devices(self, max_devices):
        """Sets the max_devices of this DefaultTenantProfileConfiguration.


        :param max_devices: The max_devices of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_devices = max_devices

    @property
    def max_assets(self):
        """Gets the max_assets of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_assets of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_assets

    @max_assets.setter
    def max_assets(self, max_assets):
        """Sets the max_assets of this DefaultTenantProfileConfiguration.


        :param max_assets: The max_assets of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_assets = max_assets

    @property
    def max_customers(self):
        """Gets the max_customers of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_customers of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_customers

    @max_customers.setter
    def max_customers(self, max_customers):
        """Sets the max_customers of this DefaultTenantProfileConfiguration.


        :param max_customers: The max_customers of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_customers = max_customers

    @property
    def max_users(self):
        """Gets the max_users of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_users of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_users

    @max_users.setter
    def max_users(self, max_users):
        """Sets the max_users of this DefaultTenantProfileConfiguration.


        :param max_users: The max_users of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_users = max_users

    @property
    def max_dashboards(self):
        """Gets the max_dashboards of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_dashboards of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_dashboards

    @max_dashboards.setter
    def max_dashboards(self, max_dashboards):
        """Sets the max_dashboards of this DefaultTenantProfileConfiguration.


        :param max_dashboards: The max_dashboards of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_dashboards = max_dashboards

    @property
    def max_rule_chains(self):
        """Gets the max_rule_chains of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_rule_chains of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_rule_chains

    @max_rule_chains.setter
    def max_rule_chains(self, max_rule_chains):
        """Sets the max_rule_chains of this DefaultTenantProfileConfiguration.


        :param max_rule_chains: The max_rule_chains of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_rule_chains = max_rule_chains

    @property
    def max_resources_in_bytes(self):
        """Gets the max_resources_in_bytes of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_resources_in_bytes of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_resources_in_bytes

    @max_resources_in_bytes.setter
    def max_resources_in_bytes(self, max_resources_in_bytes):
        """Sets the max_resources_in_bytes of this DefaultTenantProfileConfiguration.


        :param max_resources_in_bytes: The max_resources_in_bytes of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_resources_in_bytes = max_resources_in_bytes

    @property
    def max_ota_packages_in_bytes(self):
        """Gets the max_ota_packages_in_bytes of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ota_packages_in_bytes of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ota_packages_in_bytes

    @max_ota_packages_in_bytes.setter
    def max_ota_packages_in_bytes(self, max_ota_packages_in_bytes):
        """Sets the max_ota_packages_in_bytes of this DefaultTenantProfileConfiguration.


        :param max_ota_packages_in_bytes: The max_ota_packages_in_bytes of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ota_packages_in_bytes = max_ota_packages_in_bytes

    @property
    def max_resource_size(self):
        """Gets the max_resource_size of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_resource_size of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_resource_size

    @max_resource_size.setter
    def max_resource_size(self, max_resource_size):
        """Sets the max_resource_size of this DefaultTenantProfileConfiguration.


        :param max_resource_size: The max_resource_size of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_resource_size = max_resource_size

    @property
    def max_integrations(self):
        """Gets the max_integrations of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_integrations of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_integrations

    @max_integrations.setter
    def max_integrations(self, max_integrations):
        """Sets the max_integrations of this DefaultTenantProfileConfiguration.


        :param max_integrations: The max_integrations of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_integrations = max_integrations

    @property
    def max_converters(self):
        """Gets the max_converters of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_converters of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_converters

    @max_converters.setter
    def max_converters(self, max_converters):
        """Sets the max_converters of this DefaultTenantProfileConfiguration.


        :param max_converters: The max_converters of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_converters = max_converters

    @property
    def max_scheduler_events(self):
        """Gets the max_scheduler_events of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_scheduler_events of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_scheduler_events

    @max_scheduler_events.setter
    def max_scheduler_events(self, max_scheduler_events):
        """Sets the max_scheduler_events of this DefaultTenantProfileConfiguration.


        :param max_scheduler_events: The max_scheduler_events of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_scheduler_events = max_scheduler_events

    @property
    def transport_tenant_msg_rate_limit(self):
        """Gets the transport_tenant_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_tenant_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_tenant_msg_rate_limit

    @transport_tenant_msg_rate_limit.setter
    def transport_tenant_msg_rate_limit(self, transport_tenant_msg_rate_limit):
        """Sets the transport_tenant_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_tenant_msg_rate_limit: The transport_tenant_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_tenant_msg_rate_limit = transport_tenant_msg_rate_limit

    @property
    def transport_tenant_telemetry_msg_rate_limit(self):
        """Gets the transport_tenant_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_tenant_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_tenant_telemetry_msg_rate_limit

    @transport_tenant_telemetry_msg_rate_limit.setter
    def transport_tenant_telemetry_msg_rate_limit(self, transport_tenant_telemetry_msg_rate_limit):
        """Sets the transport_tenant_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_tenant_telemetry_msg_rate_limit: The transport_tenant_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_tenant_telemetry_msg_rate_limit = transport_tenant_telemetry_msg_rate_limit

    @property
    def transport_tenant_telemetry_data_points_rate_limit(self):
        """Gets the transport_tenant_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_tenant_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_tenant_telemetry_data_points_rate_limit

    @transport_tenant_telemetry_data_points_rate_limit.setter
    def transport_tenant_telemetry_data_points_rate_limit(self, transport_tenant_telemetry_data_points_rate_limit):
        """Sets the transport_tenant_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_tenant_telemetry_data_points_rate_limit: The transport_tenant_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_tenant_telemetry_data_points_rate_limit = transport_tenant_telemetry_data_points_rate_limit

    @property
    def transport_device_msg_rate_limit(self):
        """Gets the transport_device_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_device_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_device_msg_rate_limit

    @transport_device_msg_rate_limit.setter
    def transport_device_msg_rate_limit(self, transport_device_msg_rate_limit):
        """Sets the transport_device_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_device_msg_rate_limit: The transport_device_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_device_msg_rate_limit = transport_device_msg_rate_limit

    @property
    def transport_device_telemetry_msg_rate_limit(self):
        """Gets the transport_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_device_telemetry_msg_rate_limit

    @transport_device_telemetry_msg_rate_limit.setter
    def transport_device_telemetry_msg_rate_limit(self, transport_device_telemetry_msg_rate_limit):
        """Sets the transport_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_device_telemetry_msg_rate_limit: The transport_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_device_telemetry_msg_rate_limit = transport_device_telemetry_msg_rate_limit

    @property
    def transport_device_telemetry_data_points_rate_limit(self):
        """Gets the transport_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_device_telemetry_data_points_rate_limit

    @transport_device_telemetry_data_points_rate_limit.setter
    def transport_device_telemetry_data_points_rate_limit(self, transport_device_telemetry_data_points_rate_limit):
        """Sets the transport_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_device_telemetry_data_points_rate_limit: The transport_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_device_telemetry_data_points_rate_limit = transport_device_telemetry_data_points_rate_limit

    @property
    def transport_gateway_msg_rate_limit(self):
        """Gets the transport_gateway_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_gateway_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_gateway_msg_rate_limit

    @transport_gateway_msg_rate_limit.setter
    def transport_gateway_msg_rate_limit(self, transport_gateway_msg_rate_limit):
        """Sets the transport_gateway_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_gateway_msg_rate_limit: The transport_gateway_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_gateway_msg_rate_limit = transport_gateway_msg_rate_limit

    @property
    def transport_gateway_telemetry_msg_rate_limit(self):
        """Gets the transport_gateway_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_gateway_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_gateway_telemetry_msg_rate_limit

    @transport_gateway_telemetry_msg_rate_limit.setter
    def transport_gateway_telemetry_msg_rate_limit(self, transport_gateway_telemetry_msg_rate_limit):
        """Sets the transport_gateway_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_gateway_telemetry_msg_rate_limit: The transport_gateway_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_gateway_telemetry_msg_rate_limit = transport_gateway_telemetry_msg_rate_limit

    @property
    def transport_gateway_telemetry_data_points_rate_limit(self):
        """Gets the transport_gateway_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_gateway_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_gateway_telemetry_data_points_rate_limit

    @transport_gateway_telemetry_data_points_rate_limit.setter
    def transport_gateway_telemetry_data_points_rate_limit(self, transport_gateway_telemetry_data_points_rate_limit):
        """Sets the transport_gateway_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_gateway_telemetry_data_points_rate_limit: The transport_gateway_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_gateway_telemetry_data_points_rate_limit = transport_gateway_telemetry_data_points_rate_limit

    @property
    def transport_gateway_device_msg_rate_limit(self):
        """Gets the transport_gateway_device_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_gateway_device_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_gateway_device_msg_rate_limit

    @transport_gateway_device_msg_rate_limit.setter
    def transport_gateway_device_msg_rate_limit(self, transport_gateway_device_msg_rate_limit):
        """Sets the transport_gateway_device_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_gateway_device_msg_rate_limit: The transport_gateway_device_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_gateway_device_msg_rate_limit = transport_gateway_device_msg_rate_limit

    @property
    def transport_gateway_device_telemetry_msg_rate_limit(self):
        """Gets the transport_gateway_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_gateway_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_gateway_device_telemetry_msg_rate_limit

    @transport_gateway_device_telemetry_msg_rate_limit.setter
    def transport_gateway_device_telemetry_msg_rate_limit(self, transport_gateway_device_telemetry_msg_rate_limit):
        """Sets the transport_gateway_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_gateway_device_telemetry_msg_rate_limit: The transport_gateway_device_telemetry_msg_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_gateway_device_telemetry_msg_rate_limit = transport_gateway_device_telemetry_msg_rate_limit

    @property
    def transport_gateway_device_telemetry_data_points_rate_limit(self):
        """Gets the transport_gateway_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The transport_gateway_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._transport_gateway_device_telemetry_data_points_rate_limit

    @transport_gateway_device_telemetry_data_points_rate_limit.setter
    def transport_gateway_device_telemetry_data_points_rate_limit(self, transport_gateway_device_telemetry_data_points_rate_limit):
        """Sets the transport_gateway_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.


        :param transport_gateway_device_telemetry_data_points_rate_limit: The transport_gateway_device_telemetry_data_points_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._transport_gateway_device_telemetry_data_points_rate_limit = transport_gateway_device_telemetry_data_points_rate_limit

    @property
    def integration_msgs_per_tenant_rate_limit(self):
        """Gets the integration_msgs_per_tenant_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The integration_msgs_per_tenant_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._integration_msgs_per_tenant_rate_limit

    @integration_msgs_per_tenant_rate_limit.setter
    def integration_msgs_per_tenant_rate_limit(self, integration_msgs_per_tenant_rate_limit):
        """Sets the integration_msgs_per_tenant_rate_limit of this DefaultTenantProfileConfiguration.


        :param integration_msgs_per_tenant_rate_limit: The integration_msgs_per_tenant_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._integration_msgs_per_tenant_rate_limit = integration_msgs_per_tenant_rate_limit

    @property
    def integration_msgs_per_device_rate_limit(self):
        """Gets the integration_msgs_per_device_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The integration_msgs_per_device_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._integration_msgs_per_device_rate_limit

    @integration_msgs_per_device_rate_limit.setter
    def integration_msgs_per_device_rate_limit(self, integration_msgs_per_device_rate_limit):
        """Sets the integration_msgs_per_device_rate_limit of this DefaultTenantProfileConfiguration.


        :param integration_msgs_per_device_rate_limit: The integration_msgs_per_device_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._integration_msgs_per_device_rate_limit = integration_msgs_per_device_rate_limit

    @property
    def tenant_entity_export_rate_limit(self):
        """Gets the tenant_entity_export_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The tenant_entity_export_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._tenant_entity_export_rate_limit

    @tenant_entity_export_rate_limit.setter
    def tenant_entity_export_rate_limit(self, tenant_entity_export_rate_limit):
        """Sets the tenant_entity_export_rate_limit of this DefaultTenantProfileConfiguration.


        :param tenant_entity_export_rate_limit: The tenant_entity_export_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._tenant_entity_export_rate_limit = tenant_entity_export_rate_limit

    @property
    def tenant_entity_import_rate_limit(self):
        """Gets the tenant_entity_import_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The tenant_entity_import_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._tenant_entity_import_rate_limit

    @tenant_entity_import_rate_limit.setter
    def tenant_entity_import_rate_limit(self, tenant_entity_import_rate_limit):
        """Sets the tenant_entity_import_rate_limit of this DefaultTenantProfileConfiguration.


        :param tenant_entity_import_rate_limit: The tenant_entity_import_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._tenant_entity_import_rate_limit = tenant_entity_import_rate_limit

    @property
    def tenant_notification_requests_rate_limit(self):
        """Gets the tenant_notification_requests_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The tenant_notification_requests_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._tenant_notification_requests_rate_limit

    @tenant_notification_requests_rate_limit.setter
    def tenant_notification_requests_rate_limit(self, tenant_notification_requests_rate_limit):
        """Sets the tenant_notification_requests_rate_limit of this DefaultTenantProfileConfiguration.


        :param tenant_notification_requests_rate_limit: The tenant_notification_requests_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._tenant_notification_requests_rate_limit = tenant_notification_requests_rate_limit

    @property
    def tenant_notification_requests_per_rule_rate_limit(self):
        """Gets the tenant_notification_requests_per_rule_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The tenant_notification_requests_per_rule_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._tenant_notification_requests_per_rule_rate_limit

    @tenant_notification_requests_per_rule_rate_limit.setter
    def tenant_notification_requests_per_rule_rate_limit(self, tenant_notification_requests_per_rule_rate_limit):
        """Sets the tenant_notification_requests_per_rule_rate_limit of this DefaultTenantProfileConfiguration.


        :param tenant_notification_requests_per_rule_rate_limit: The tenant_notification_requests_per_rule_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._tenant_notification_requests_per_rule_rate_limit = tenant_notification_requests_per_rule_rate_limit

    @property
    def max_transport_messages(self):
        """Gets the max_transport_messages of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_transport_messages of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_transport_messages

    @max_transport_messages.setter
    def max_transport_messages(self, max_transport_messages):
        """Sets the max_transport_messages of this DefaultTenantProfileConfiguration.


        :param max_transport_messages: The max_transport_messages of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_transport_messages = max_transport_messages

    @property
    def max_transport_data_points(self):
        """Gets the max_transport_data_points of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_transport_data_points of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_transport_data_points

    @max_transport_data_points.setter
    def max_transport_data_points(self, max_transport_data_points):
        """Sets the max_transport_data_points of this DefaultTenantProfileConfiguration.


        :param max_transport_data_points: The max_transport_data_points of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_transport_data_points = max_transport_data_points

    @property
    def max_re_executions(self):
        """Gets the max_re_executions of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_re_executions of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_re_executions

    @max_re_executions.setter
    def max_re_executions(self, max_re_executions):
        """Sets the max_re_executions of this DefaultTenantProfileConfiguration.


        :param max_re_executions: The max_re_executions of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_re_executions = max_re_executions

    @property
    def max_js_executions(self):
        """Gets the max_js_executions of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_js_executions of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_js_executions

    @max_js_executions.setter
    def max_js_executions(self, max_js_executions):
        """Sets the max_js_executions of this DefaultTenantProfileConfiguration.


        :param max_js_executions: The max_js_executions of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_js_executions = max_js_executions

    @property
    def max_tbel_executions(self):
        """Gets the max_tbel_executions of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_tbel_executions of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_tbel_executions

    @max_tbel_executions.setter
    def max_tbel_executions(self, max_tbel_executions):
        """Sets the max_tbel_executions of this DefaultTenantProfileConfiguration.


        :param max_tbel_executions: The max_tbel_executions of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_tbel_executions = max_tbel_executions

    @property
    def max_dp_storage_days(self):
        """Gets the max_dp_storage_days of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_dp_storage_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_dp_storage_days

    @max_dp_storage_days.setter
    def max_dp_storage_days(self, max_dp_storage_days):
        """Sets the max_dp_storage_days of this DefaultTenantProfileConfiguration.


        :param max_dp_storage_days: The max_dp_storage_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_dp_storage_days = max_dp_storage_days

    @property
    def max_rule_node_executions_per_message(self):
        """Gets the max_rule_node_executions_per_message of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_rule_node_executions_per_message of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_rule_node_executions_per_message

    @max_rule_node_executions_per_message.setter
    def max_rule_node_executions_per_message(self, max_rule_node_executions_per_message):
        """Sets the max_rule_node_executions_per_message of this DefaultTenantProfileConfiguration.


        :param max_rule_node_executions_per_message: The max_rule_node_executions_per_message of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_rule_node_executions_per_message = max_rule_node_executions_per_message

    @property
    def max_emails(self):
        """Gets the max_emails of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_emails of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_emails

    @max_emails.setter
    def max_emails(self, max_emails):
        """Sets the max_emails of this DefaultTenantProfileConfiguration.


        :param max_emails: The max_emails of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_emails = max_emails

    @property
    def sms_enabled(self):
        """Gets the sms_enabled of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The sms_enabled of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._sms_enabled

    @sms_enabled.setter
    def sms_enabled(self, sms_enabled):
        """Sets the sms_enabled of this DefaultTenantProfileConfiguration.


        :param sms_enabled: The sms_enabled of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: bool
        """

        self._sms_enabled = sms_enabled

    @property
    def max_sms(self):
        """Gets the max_sms of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_sms of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_sms

    @max_sms.setter
    def max_sms(self, max_sms):
        """Sets the max_sms of this DefaultTenantProfileConfiguration.


        :param max_sms: The max_sms of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_sms = max_sms

    @property
    def max_created_alarms(self):
        """Gets the max_created_alarms of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_created_alarms of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_created_alarms

    @max_created_alarms.setter
    def max_created_alarms(self, max_created_alarms):
        """Sets the max_created_alarms of this DefaultTenantProfileConfiguration.


        :param max_created_alarms: The max_created_alarms of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_created_alarms = max_created_alarms

    @property
    def tenant_server_rest_limits_configuration(self):
        """Gets the tenant_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The tenant_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._tenant_server_rest_limits_configuration

    @tenant_server_rest_limits_configuration.setter
    def tenant_server_rest_limits_configuration(self, tenant_server_rest_limits_configuration):
        """Sets the tenant_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.


        :param tenant_server_rest_limits_configuration: The tenant_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._tenant_server_rest_limits_configuration = tenant_server_rest_limits_configuration

    @property
    def customer_server_rest_limits_configuration(self):
        """Gets the customer_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The customer_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._customer_server_rest_limits_configuration

    @customer_server_rest_limits_configuration.setter
    def customer_server_rest_limits_configuration(self, customer_server_rest_limits_configuration):
        """Sets the customer_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.


        :param customer_server_rest_limits_configuration: The customer_server_rest_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._customer_server_rest_limits_configuration = customer_server_rest_limits_configuration

    @property
    def max_ws_sessions_per_tenant(self):
        """Gets the max_ws_sessions_per_tenant of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_sessions_per_tenant of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_sessions_per_tenant

    @max_ws_sessions_per_tenant.setter
    def max_ws_sessions_per_tenant(self, max_ws_sessions_per_tenant):
        """Sets the max_ws_sessions_per_tenant of this DefaultTenantProfileConfiguration.


        :param max_ws_sessions_per_tenant: The max_ws_sessions_per_tenant of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_sessions_per_tenant = max_ws_sessions_per_tenant

    @property
    def max_ws_sessions_per_customer(self):
        """Gets the max_ws_sessions_per_customer of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_sessions_per_customer of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_sessions_per_customer

    @max_ws_sessions_per_customer.setter
    def max_ws_sessions_per_customer(self, max_ws_sessions_per_customer):
        """Sets the max_ws_sessions_per_customer of this DefaultTenantProfileConfiguration.


        :param max_ws_sessions_per_customer: The max_ws_sessions_per_customer of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_sessions_per_customer = max_ws_sessions_per_customer

    @property
    def max_ws_sessions_per_regular_user(self):
        """Gets the max_ws_sessions_per_regular_user of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_sessions_per_regular_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_sessions_per_regular_user

    @max_ws_sessions_per_regular_user.setter
    def max_ws_sessions_per_regular_user(self, max_ws_sessions_per_regular_user):
        """Sets the max_ws_sessions_per_regular_user of this DefaultTenantProfileConfiguration.


        :param max_ws_sessions_per_regular_user: The max_ws_sessions_per_regular_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_sessions_per_regular_user = max_ws_sessions_per_regular_user

    @property
    def max_ws_sessions_per_public_user(self):
        """Gets the max_ws_sessions_per_public_user of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_sessions_per_public_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_sessions_per_public_user

    @max_ws_sessions_per_public_user.setter
    def max_ws_sessions_per_public_user(self, max_ws_sessions_per_public_user):
        """Sets the max_ws_sessions_per_public_user of this DefaultTenantProfileConfiguration.


        :param max_ws_sessions_per_public_user: The max_ws_sessions_per_public_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_sessions_per_public_user = max_ws_sessions_per_public_user

    @property
    def ws_msg_queue_limit_per_session(self):
        """Gets the ws_msg_queue_limit_per_session of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The ws_msg_queue_limit_per_session of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._ws_msg_queue_limit_per_session

    @ws_msg_queue_limit_per_session.setter
    def ws_msg_queue_limit_per_session(self, ws_msg_queue_limit_per_session):
        """Sets the ws_msg_queue_limit_per_session of this DefaultTenantProfileConfiguration.


        :param ws_msg_queue_limit_per_session: The ws_msg_queue_limit_per_session of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._ws_msg_queue_limit_per_session = ws_msg_queue_limit_per_session

    @property
    def max_ws_subscriptions_per_tenant(self):
        """Gets the max_ws_subscriptions_per_tenant of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_subscriptions_per_tenant of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_subscriptions_per_tenant

    @max_ws_subscriptions_per_tenant.setter
    def max_ws_subscriptions_per_tenant(self, max_ws_subscriptions_per_tenant):
        """Sets the max_ws_subscriptions_per_tenant of this DefaultTenantProfileConfiguration.


        :param max_ws_subscriptions_per_tenant: The max_ws_subscriptions_per_tenant of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_subscriptions_per_tenant = max_ws_subscriptions_per_tenant

    @property
    def max_ws_subscriptions_per_customer(self):
        """Gets the max_ws_subscriptions_per_customer of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_subscriptions_per_customer of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_subscriptions_per_customer

    @max_ws_subscriptions_per_customer.setter
    def max_ws_subscriptions_per_customer(self, max_ws_subscriptions_per_customer):
        """Sets the max_ws_subscriptions_per_customer of this DefaultTenantProfileConfiguration.


        :param max_ws_subscriptions_per_customer: The max_ws_subscriptions_per_customer of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_subscriptions_per_customer = max_ws_subscriptions_per_customer

    @property
    def max_ws_subscriptions_per_regular_user(self):
        """Gets the max_ws_subscriptions_per_regular_user of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_subscriptions_per_regular_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_subscriptions_per_regular_user

    @max_ws_subscriptions_per_regular_user.setter
    def max_ws_subscriptions_per_regular_user(self, max_ws_subscriptions_per_regular_user):
        """Sets the max_ws_subscriptions_per_regular_user of this DefaultTenantProfileConfiguration.


        :param max_ws_subscriptions_per_regular_user: The max_ws_subscriptions_per_regular_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_subscriptions_per_regular_user = max_ws_subscriptions_per_regular_user

    @property
    def max_ws_subscriptions_per_public_user(self):
        """Gets the max_ws_subscriptions_per_public_user of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The max_ws_subscriptions_per_public_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._max_ws_subscriptions_per_public_user

    @max_ws_subscriptions_per_public_user.setter
    def max_ws_subscriptions_per_public_user(self, max_ws_subscriptions_per_public_user):
        """Sets the max_ws_subscriptions_per_public_user of this DefaultTenantProfileConfiguration.


        :param max_ws_subscriptions_per_public_user: The max_ws_subscriptions_per_public_user of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._max_ws_subscriptions_per_public_user = max_ws_subscriptions_per_public_user

    @property
    def ws_updates_per_session_rate_limit(self):
        """Gets the ws_updates_per_session_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The ws_updates_per_session_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._ws_updates_per_session_rate_limit

    @ws_updates_per_session_rate_limit.setter
    def ws_updates_per_session_rate_limit(self, ws_updates_per_session_rate_limit):
        """Sets the ws_updates_per_session_rate_limit of this DefaultTenantProfileConfiguration.


        :param ws_updates_per_session_rate_limit: The ws_updates_per_session_rate_limit of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._ws_updates_per_session_rate_limit = ws_updates_per_session_rate_limit

    @property
    def cassandra_query_tenant_rate_limits_configuration(self):
        """Gets the cassandra_query_tenant_rate_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The cassandra_query_tenant_rate_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._cassandra_query_tenant_rate_limits_configuration

    @cassandra_query_tenant_rate_limits_configuration.setter
    def cassandra_query_tenant_rate_limits_configuration(self, cassandra_query_tenant_rate_limits_configuration):
        """Sets the cassandra_query_tenant_rate_limits_configuration of this DefaultTenantProfileConfiguration.


        :param cassandra_query_tenant_rate_limits_configuration: The cassandra_query_tenant_rate_limits_configuration of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._cassandra_query_tenant_rate_limits_configuration = cassandra_query_tenant_rate_limits_configuration

    @property
    def edge_event_rate_limits(self):
        """Gets the edge_event_rate_limits of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The edge_event_rate_limits of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._edge_event_rate_limits

    @edge_event_rate_limits.setter
    def edge_event_rate_limits(self, edge_event_rate_limits):
        """Sets the edge_event_rate_limits of this DefaultTenantProfileConfiguration.


        :param edge_event_rate_limits: The edge_event_rate_limits of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._edge_event_rate_limits = edge_event_rate_limits

    @property
    def edge_event_rate_limits_per_edge(self):
        """Gets the edge_event_rate_limits_per_edge of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The edge_event_rate_limits_per_edge of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._edge_event_rate_limits_per_edge

    @edge_event_rate_limits_per_edge.setter
    def edge_event_rate_limits_per_edge(self, edge_event_rate_limits_per_edge):
        """Sets the edge_event_rate_limits_per_edge of this DefaultTenantProfileConfiguration.


        :param edge_event_rate_limits_per_edge: The edge_event_rate_limits_per_edge of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._edge_event_rate_limits_per_edge = edge_event_rate_limits_per_edge

    @property
    def edge_uplink_messages_rate_limits(self):
        """Gets the edge_uplink_messages_rate_limits of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The edge_uplink_messages_rate_limits of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._edge_uplink_messages_rate_limits

    @edge_uplink_messages_rate_limits.setter
    def edge_uplink_messages_rate_limits(self, edge_uplink_messages_rate_limits):
        """Sets the edge_uplink_messages_rate_limits of this DefaultTenantProfileConfiguration.


        :param edge_uplink_messages_rate_limits: The edge_uplink_messages_rate_limits of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._edge_uplink_messages_rate_limits = edge_uplink_messages_rate_limits

    @property
    def edge_uplink_messages_rate_limits_per_edge(self):
        """Gets the edge_uplink_messages_rate_limits_per_edge of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The edge_uplink_messages_rate_limits_per_edge of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._edge_uplink_messages_rate_limits_per_edge

    @edge_uplink_messages_rate_limits_per_edge.setter
    def edge_uplink_messages_rate_limits_per_edge(self, edge_uplink_messages_rate_limits_per_edge):
        """Sets the edge_uplink_messages_rate_limits_per_edge of this DefaultTenantProfileConfiguration.


        :param edge_uplink_messages_rate_limits_per_edge: The edge_uplink_messages_rate_limits_per_edge of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: str
        """

        self._edge_uplink_messages_rate_limits_per_edge = edge_uplink_messages_rate_limits_per_edge

    @property
    def default_storage_ttl_days(self):
        """Gets the default_storage_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The default_storage_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._default_storage_ttl_days

    @default_storage_ttl_days.setter
    def default_storage_ttl_days(self, default_storage_ttl_days):
        """Sets the default_storage_ttl_days of this DefaultTenantProfileConfiguration.


        :param default_storage_ttl_days: The default_storage_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._default_storage_ttl_days = default_storage_ttl_days

    @property
    def alarms_ttl_days(self):
        """Gets the alarms_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The alarms_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._alarms_ttl_days

    @alarms_ttl_days.setter
    def alarms_ttl_days(self, alarms_ttl_days):
        """Sets the alarms_ttl_days of this DefaultTenantProfileConfiguration.


        :param alarms_ttl_days: The alarms_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._alarms_ttl_days = alarms_ttl_days

    @property
    def rpc_ttl_days(self):
        """Gets the rpc_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The rpc_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._rpc_ttl_days

    @rpc_ttl_days.setter
    def rpc_ttl_days(self, rpc_ttl_days):
        """Sets the rpc_ttl_days of this DefaultTenantProfileConfiguration.


        :param rpc_ttl_days: The rpc_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._rpc_ttl_days = rpc_ttl_days

    @property
    def queue_stats_ttl_days(self):
        """Gets the queue_stats_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The queue_stats_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._queue_stats_ttl_days

    @queue_stats_ttl_days.setter
    def queue_stats_ttl_days(self, queue_stats_ttl_days):
        """Sets the queue_stats_ttl_days of this DefaultTenantProfileConfiguration.


        :param queue_stats_ttl_days: The queue_stats_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._queue_stats_ttl_days = queue_stats_ttl_days

    @property
    def rule_engine_exceptions_ttl_days(self):
        """Gets the rule_engine_exceptions_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The rule_engine_exceptions_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._rule_engine_exceptions_ttl_days

    @rule_engine_exceptions_ttl_days.setter
    def rule_engine_exceptions_ttl_days(self, rule_engine_exceptions_ttl_days):
        """Sets the rule_engine_exceptions_ttl_days of this DefaultTenantProfileConfiguration.


        :param rule_engine_exceptions_ttl_days: The rule_engine_exceptions_ttl_days of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: int
        """

        self._rule_engine_exceptions_ttl_days = rule_engine_exceptions_ttl_days

    @property
    def warn_threshold(self):
        """Gets the warn_threshold of this DefaultTenantProfileConfiguration.  # noqa: E501


        :return: The warn_threshold of this DefaultTenantProfileConfiguration.  # noqa: E501
        :rtype: float
        """
        return self._warn_threshold

    @warn_threshold.setter
    def warn_threshold(self, warn_threshold):
        """Sets the warn_threshold of this DefaultTenantProfileConfiguration.


        :param warn_threshold: The warn_threshold of this DefaultTenantProfileConfiguration.  # noqa: E501
        :type: float
        """

        self._warn_threshold = warn_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DefaultTenantProfileConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DefaultTenantProfileConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class SystemInfoData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'service_id': 'str',
        'service_type': 'str',
        'cpu_usage': 'int',
        'cpu_count': 'int',
        'memory_usage': 'int',
        'total_memory': 'int',
        'disc_usage': 'int',
        'total_disc_space': 'int'
    }

    attribute_map = {
        'service_id': 'serviceId',
        'service_type': 'serviceType',
        'cpu_usage': 'cpuUsage',
        'cpu_count': 'cpuCount',
        'memory_usage': 'memoryUsage',
        'total_memory': 'totalMemory',
        'disc_usage': 'discUsage',
        'total_disc_space': 'totalDiscSpace'
    }

    def __init__(self, service_id=None, service_type=None, cpu_usage=None, cpu_count=None, memory_usage=None, total_memory=None, disc_usage=None, total_disc_space=None):  # noqa: E501
        """SystemInfoData - a model defined in Swagger"""  # noqa: E501
        self._service_id = None
        self._service_type = None
        self._cpu_usage = None
        self._cpu_count = None
        self._memory_usage = None
        self._total_memory = None
        self._disc_usage = None
        self._total_disc_space = None
        self.discriminator = None
        if service_id is not None:
            self.service_id = service_id
        if service_type is not None:
            self.service_type = service_type
        if cpu_usage is not None:
            self.cpu_usage = cpu_usage
        if cpu_count is not None:
            self.cpu_count = cpu_count
        if memory_usage is not None:
            self.memory_usage = memory_usage
        if total_memory is not None:
            self.total_memory = total_memory
        if disc_usage is not None:
            self.disc_usage = disc_usage
        if total_disc_space is not None:
            self.total_disc_space = total_disc_space

    @property
    def service_id(self):
        """Gets the service_id of this SystemInfoData.  # noqa: E501

        Service Id.  # noqa: E501

        :return: The service_id of this SystemInfoData.  # noqa: E501
        :rtype: str
        """
        return self._service_id

    @service_id.setter
    def service_id(self, service_id):
        """Sets the service_id of this SystemInfoData.

        Service Id.  # noqa: E501

        :param service_id: The service_id of this SystemInfoData.  # noqa: E501
        :type: str
        """

        self._service_id = service_id

    @property
    def service_type(self):
        """Gets the service_type of this SystemInfoData.  # noqa: E501

        Service type.  # noqa: E501

        :return: The service_type of this SystemInfoData.  # noqa: E501
        :rtype: str
        """
        return self._service_type

    @service_type.setter
    def service_type(self, service_type):
        """Sets the service_type of this SystemInfoData.

        Service type.  # noqa: E501

        :param service_type: The service_type of this SystemInfoData.  # noqa: E501
        :type: str
        """

        self._service_type = service_type

    @property
    def cpu_usage(self):
        """Gets the cpu_usage of this SystemInfoData.  # noqa: E501

        CPU usage, in percent.  # noqa: E501

        :return: The cpu_usage of this SystemInfoData.  # noqa: E501
        :rtype: int
        """
        return self._cpu_usage

    @cpu_usage.setter
    def cpu_usage(self, cpu_usage):
        """Sets the cpu_usage of this SystemInfoData.

        CPU usage, in percent.  # noqa: E501

        :param cpu_usage: The cpu_usage of this SystemInfoData.  # noqa: E501
        :type: int
        """

        self._cpu_usage = cpu_usage

    @property
    def cpu_count(self):
        """Gets the cpu_count of this SystemInfoData.  # noqa: E501

        Total CPU usage.  # noqa: E501

        :return: The cpu_count of this SystemInfoData.  # noqa: E501
        :rtype: int
        """
        return self._cpu_count

    @cpu_count.setter
    def cpu_count(self, cpu_count):
        """Sets the cpu_count of this SystemInfoData.

        Total CPU usage.  # noqa: E501

        :param cpu_count: The cpu_count of this SystemInfoData.  # noqa: E501
        :type: int
        """

        self._cpu_count = cpu_count

    @property
    def memory_usage(self):
        """Gets the memory_usage of this SystemInfoData.  # noqa: E501

        Memory usage, in percent.  # noqa: E501

        :return: The memory_usage of this SystemInfoData.  # noqa: E501
        :rtype: int
        """
        return self._memory_usage

    @memory_usage.setter
    def memory_usage(self, memory_usage):
        """Sets the memory_usage of this SystemInfoData.

        Memory usage, in percent.  # noqa: E501

        :param memory_usage: The memory_usage of this SystemInfoData.  # noqa: E501
        :type: int
        """

        self._memory_usage = memory_usage

    @property
    def total_memory(self):
        """Gets the total_memory of this SystemInfoData.  # noqa: E501

        Total memory in bytes.  # noqa: E501

        :return: The total_memory of this SystemInfoData.  # noqa: E501
        :rtype: int
        """
        return self._total_memory

    @total_memory.setter
    def total_memory(self, total_memory):
        """Sets the total_memory of this SystemInfoData.

        Total memory in bytes.  # noqa: E501

        :param total_memory: The total_memory of this SystemInfoData.  # noqa: E501
        :type: int
        """

        self._total_memory = total_memory

    @property
    def disc_usage(self):
        """Gets the disc_usage of this SystemInfoData.  # noqa: E501

        Disk usage, in percent.  # noqa: E501

        :return: The disc_usage of this SystemInfoData.  # noqa: E501
        :rtype: int
        """
        return self._disc_usage

    @disc_usage.setter
    def disc_usage(self, disc_usage):
        """Sets the disc_usage of this SystemInfoData.

        Disk usage, in percent.  # noqa: E501

        :param disc_usage: The disc_usage of this SystemInfoData.  # noqa: E501
        :type: int
        """

        self._disc_usage = disc_usage

    @property
    def total_disc_space(self):
        """Gets the total_disc_space of this SystemInfoData.  # noqa: E501

        Total disc space in bytes.  # noqa: E501

        :return: The total_disc_space of this SystemInfoData.  # noqa: E501
        :rtype: int
        """
        return self._total_disc_space

    @total_disc_space.setter
    def total_disc_space(self, total_disc_space):
        """Sets the total_disc_space of this SystemInfoData.

        Total disc space in bytes.  # noqa: E501

        :param total_disc_space: The total_disc_space of this SystemInfoData.  # noqa: E501
        :type: int
        """

        self._total_disc_space = total_disc_space

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SystemInfoData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemInfoData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
